# vim:tw=0:ts=4:sw=4:et
%define major 2
%define minor 2
%define micro 9
%define extra %{nil}
%define release_version %{major}.%{minor}.%{micro}%{extra}

# required by suse build system
# norootforbuild

%define run_unit_tests 1
%{?_without_unit_tests: %define run_unit_tests 0}
%{?_with_unit_tests:    %define run_unit_tests 1}

%define python_xml_BR %{nil}
# Some variable definitions so that we can be compatible between SUSE Build service and Fedora build system
# SUSE: fedora_version  suse_version rhel_version centos_version sles_version
# Fedora: fedora dist fc8 fc9
%if 0%{?suse_version} || 0%{?sles_version}
    %define python_xml_BR python-xml
%endif

# per fedora python packaging guidelines
%{!?python_sitelib: %define python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}

# no debuginfo package, as there are no compiled binaries.
%define debug_package %{nil}

Name:           firmware-addon-dell
Version:        %{release_version}
Release:        12%{?dist}
Summary:        A firmware-tools plugin to handle BIOS/Firmware for Dell systems

Group:          Applications/System
License:        GPLv2+ or OSL 2.1
URL:            http://linux.dell.com/libsmbios/download/
Source0:        http://linux.dell.com/libsmbios/download/%{name}/%{name}-%{version}/%{name}-%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Patch0:         replace_wineprefix_with_wineboot.patch

# Dell only sells Intel-compat systems, so this package doesnt make much sense
# on, eg. PPC.  Also, we rely on libsmbios, which is only avail on Intel-compat
ExclusiveArch: x86_64 ia64 %{ix86}

BuildRequires: firmware-tools > 0:2.0
BuildRequires:  python-smbios python-devel %{python_xml_BR}

Requires: smbios-utils python-smbios
Requires: firmware-tools >= 0:2.0.0
Provides: firmware_inventory(system_bios)  = 0:%{version}

%description
The firmware-addon-dell package provides plugins to firmware-tools which enable
BIOS updates for Dell system, plus pulls in standard inventory modules
applicable to most Dell systems.

%prep
%setup -q
%patch0 -p1


%build
# this line lets us build an RPM directly from a git tarball
[ -e ./configure ] || ./autogen.sh

# only applicable on obs
# # fix problems when buildsystem time is out of sync. ./configure will
# # fail if newly created files are older than the packaged files.
# # this should normally be a no-op on proper buildsystems.
# touch configure
# find . -type f -newer configure -print0 | xargs -r0 touch

%configure RELEASE_MAJOR=%{major} RELEASE_MINOR=%{minor} RELEASE_MICRO=%{micro} RELEASE_EXTRA=%{extra}
make %{?_smp_mflags}

%check
%if 0%{?run_unit_tests}
make %{?_smp_mflags} check
%endif

%install
# Fedora Packaging guidelines
rm -rf $RPM_BUILD_ROOT
# SUSE Packaging rpmlint
mkdir -p $RPM_BUILD_ROOT

make install DESTDIR=%{buildroot} INSTALL="%{__install} -p"
mkdir -p $RPM_BUILD_ROOT/%{_datadir}/firmware/dell/bios


%clean
rm -rf $RPM_BUILD_ROOT


%files
%defattr(-,root,root,-)
%doc COPYING-GPL COPYING-OSL
%{python_sitelib}/*
%config(noreplace) %{_sysconfdir}/firmware/firmware.d/*.conf
%{_datadir}/firmware/dell
%{_datadir}/firmware-tools/*


%changelog
* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.9-12
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.2.9-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.9-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.9-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.9-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.9-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.9-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.9-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.9-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Fri Jun 24 2011 Praveen K Paladugu <praveen_paladugu@dell.com>
- Added a patch to fix BZ#688046.This patch uses wineboot when available and falls back to legacy winprefixcreate if not.


* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.9-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Sep 27 2010 Matt Domsch <mdomsch@fedoraproject.org> - 2.2.9-1
- update to latest upstream

* Wed Jul 21 2010 David Malcolm <dmalcolm@redhat.com> - 2.2.1-3
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Fri Dec 11 2009 Matt Domsch <mdomsch@fedoraproject.org> - 2.2.1-2
- remember to upload the tarball first

* Fri Dec 11 2009 Matt Domsch <mdomsch@fedoraproject.org> - 2.2.1-1
- rebase to latest upstream

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.2-5.3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu May 14 2009 Matt Domsch <mdomsch@fedoraproject.org> - 2.1.2-4.3
- rebase to latest upstream

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.8-2.2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Nov 29 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 1.4.8-2.1
- Rebuild for Python 2.6

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.4.8-1
- Autorebuild for GCC 4.3

* Wed Aug 22 2007 Michael E Brown <michael_e_brown at dell.com> - 1.4.7-1
- rebase to latest upstream

* Fri Aug 17 2007 Michael E Brown <michael_e_brown at dell.com> - 1.4.4-1
- rebase to latest upstream

* Wed Jul 11 2007 Michael E Brown <michael_e_brown at dell.com> - 1.3.1-1
- up2date_repo_autoconf is now obsolete. dell-*-repository files no longer
  use it.

* Sat Apr 7 2007 Michael E Brown <michael_e_brown at dell.com> - 1.2.11-1
- enhance up2date_repo_autoconf by populating default configuration file

* Fri Apr 6 2007 Michael E Brown <michael_e_brown at dell.com> - 1.2.10-1
- Couple of changes so that the dell sysid plugin work on yum 2.4.3
  prior versions didnt crash, but didnt properly substitute mirrolist
  because the name of mirrolist var is different in 2.4.3.
- Per discussion on mailing list, convert to arch-specific pkg
- package bin/up2date_repo_autoconf only for RHEL{3,4} releases

* Fri Apr 6 2007 Michael E Brown <michael_e_brown at dell.com> - 1.2.9-1
- downgrade api needed to 2.1
- Added up2date_repo_autoconf binary
- fix changes from 1.2.7 that were accidentally reverted in 1.2.8. :(

* Fri Apr 6 2007 Michael E Brown <michael_e_brown at dell.com> - 1.2.8-1
- sysid plugin: Zero pad value for sysid up to 4 chars
- sysid plugin: Add 0x to signify that it is a hex value

* Fri Mar 30 2007 Michael E Brown <michael_e_brown at dell.com> - 1.2.7-1
- yum plugin didnt work on FC5 due to extra, unneeded import.
- dont need plugin api 2.5, 2.2 will do

* Wed Mar 28 2007 Michael E Brown <michael_e_brown at dell.com> - 1.2.6-1
- Add yum plugins for setting system ID variables. repos can use $sys_ven_id
  $sys_dev_id in their baseurl= or mirrorlist= arguments.

* Sat Mar 17 2007 Michael E Brown <michael_e_brown at dell.com> - 1.2.5-1
- Add ExcludeArch for s390
- Remove python-abi dep for RHEL3 (it was broken)
- fix sitelib path missing /lib/ dir

* Fri Mar 16 2007 Michael E Brown <michael_e_brown at dell.com> - 1.2.4-1
- Add ExcludeArch to fix problem where f-a-d was being added to ppc repo

* Thu Mar 15 2007 Michael E Brown <michael_e_brown at dell.com> - 1.2.2-1
- Trivial changes to add specific {_datadir}/firmware/dell

* Thu Mar 15 2007 Michael E Brown <michael_e_brown at dell.com> - 1.2.1-1
- Trivial changes to make rpmlint happier

* Wed Mar 14 2007 Michael E Brown <michael_e_brown at dell.com> - 1.2.0-1
- Fedora-compliant packaging changes.
